# Copyright (c) 2019 - The Procedural Generation for Gazebo authors
# For information on the respective copyright owner see the NOTICE file
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ..types import XMLBase
from .pose import Pose
from .time import Time


class Waypoint(XMLBase):
    _NAME = 'waypoint'
    _TYPE = 'sdf'

    _CHILDREN_CREATORS = dict(
        time=dict(creator=Time),
        pose=dict(creator=Pose)
    )

    def __init__(self):
        super(Waypoint, self).__init__()
        self.reset()

    @property
    def time(self):
        return self._get_child_element('time')

    @time.setter
    def time(self, value):
        self._add_child_element('time', value)

    @property
    def pose(self):
        return self._get_child_element('pose')

    @pose.setter
    def pose(self, value):
        self._add_child_element('pose', value)
